"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AdminMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICEADMINMESSAGE_FIELD_NUMBER: builtins.int
    @property
    def deviceAdminMessage(self) -> global___DeviceAdminMessage: ...
    def __init__(
        self,
        *,
        deviceAdminMessage: global___DeviceAdminMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["adminMessageSubtype", b"adminMessageSubtype", "deviceAdminMessage", b"deviceAdminMessage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["adminMessageSubtype", b"adminMessageSubtype", "deviceAdminMessage", b"deviceAdminMessage"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["adminMessageSubtype", b"adminMessageSubtype"]) -> typing.Literal["deviceAdminMessage"] | None: ...

global___AdminMessage = AdminMessage

@typing.final
class DeviceAdminMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DeviceAdminMessage._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DEVICE_ADMIN_MESSAGE_TYPE_NONE: DeviceAdminMessage._Type.ValueType  # 0
        DEVICE_ADMIN_MESSAGE_TYPE_LOCAL_USER_CHANGED_IDENTITY_KEY_NAMED_DEVICE: DeviceAdminMessage._Type.ValueType  # 1
        DEVICE_ADMIN_MESSAGE_TYPE_SECURITY_ALERT_PARTICIPANT_KEY_CHANGE: DeviceAdminMessage._Type.ValueType  # 2
        DEVICE_ADMIN_MESSAGE_TYPE_SECURITY_ALERT_PARTICIPANT_NEW_LOGIN: DeviceAdminMessage._Type.ValueType  # 3

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    DEVICE_ADMIN_MESSAGE_TYPE_NONE: DeviceAdminMessage.Type.ValueType  # 0
    DEVICE_ADMIN_MESSAGE_TYPE_LOCAL_USER_CHANGED_IDENTITY_KEY_NAMED_DEVICE: DeviceAdminMessage.Type.ValueType  # 1
    DEVICE_ADMIN_MESSAGE_TYPE_SECURITY_ALERT_PARTICIPANT_KEY_CHANGE: DeviceAdminMessage.Type.ValueType  # 2
    DEVICE_ADMIN_MESSAGE_TYPE_SECURITY_ALERT_PARTICIPANT_NEW_LOGIN: DeviceAdminMessage.Type.ValueType  # 3

    DEVICEADMINMESSAGETYPE_FIELD_NUMBER: builtins.int
    DEVICENAME_FIELD_NUMBER: builtins.int
    deviceAdminMessageType: global___DeviceAdminMessage.Type.ValueType
    deviceName: builtins.str
    def __init__(
        self,
        *,
        deviceAdminMessageType: global___DeviceAdminMessage.Type.ValueType | None = ...,
        deviceName: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["deviceAdminMessageType", b"deviceAdminMessageType", "deviceName", b"deviceName"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deviceAdminMessageType", b"deviceAdminMessageType", "deviceName", b"deviceName"]) -> None: ...

global___DeviceAdminMessage = DeviceAdminMessage



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waArmadilloMiTransportAdminMessage/WAArmadilloMiTransportAdminMessage.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'waArmadilloMiTransportAdminMessage/WAArmadilloMiTransportAdminMessage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKwaArmadilloMiTransportAdminMessage/WAArmadilloMiTransportAdminMessage.proto\x12\"WAArmadilloMiTransportAdminMessage\"\xeb=\n\x17MiTransportAdminMessage\x12h\n\x10\x63hatThemeChanged\x18\x01 \x01(\x0b\x32L.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.ChatThemeChangedH\x00\x12\x66\n\x0fnicknameChanged\x18\x02 \x01(\x0b\x32K.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.NicknameChangedH\x00\x12v\n\x17groupParticipantChanged\x18\x03 \x01(\x0b\x32S.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupParticipantChangedH\x00\x12j\n\x11groupAdminChanged\x18\x04 \x01(\x0b\x32M.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupAdminChangedH\x00\x12h\n\x10groupNameChanged\x18\x05 \x01(\x0b\x32L.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupNameChangedH\x00\x12\x82\x01\n\x1dgroupMembershipAddModeChanged\x18\x06 \x01(\x0b\x32Y.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupMembershipAddModeChangedH\x00\x12\x62\n\rmessagePinned\x18\x07 \x01(\x0b\x32I.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.MessagePinnedH\x00\x12j\n\x11groupImageChanged\x18\x08 \x01(\x0b\x32M.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupImageChangedH\x00\x12p\n\x14quickReactionChanged\x18\t \x01(\x0b\x32P.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.QuickReactionChangedH\x00\x12V\n\x07linkCta\x18\n \x01(\x0b\x32\x43.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.LinkCtaH\x00\x12^\n\x0biconChanged\x18\x0b \x01(\x0b\x32G.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.IconChangedH\x00\x12|\n\x1a\x64isappearingSettingChanged\x18\x0c \x01(\x0b\x32V.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.DisappearingSettingChangedH\x00\x12n\n\x13limitSharingChanged\x18\r \x01(\x0b\x32O.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.LimitSharingChangedH\x00\x12v\n\x17xmatDisappearingSetting\x18\x0e \x01(\x0b\x32S.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatDisappearingSettingH\x00\x12\x8e\x01\n#xmatFriendRequestConfirmedEncrypted\x18\x0f \x01(\x0b\x32_.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatFriendRequestConfirmedEncryptedH\x00\x12\x9e\x01\n+xmatInstantGameEncryptedDynamicCustomUpdate\x18\x10 \x01(\x0b\x32g.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatInstantGameEncryptedDynamicCustomUpdateH\x00\x12^\n\x0bxmatLinkCta\x18\x11 \x01(\x0b\x32G.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatLinkCTAH\x00\x12\x64\n\x0exmatMagicWords\x18\x12 \x01(\x0b\x32J.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatMagicWordsH\x00\x12z\n\x19xmatMessagingLimitSharing\x18\x13 \x01(\x0b\x32U.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatMessagingLimitSharingH\x00\x12|\n\x1axmatMessengerQrCodeScanned\x18\x14 \x01(\x0b\x32V.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatMessengerQRCodeScannedH\x00\x12\x88\x01\n xmatMessengerSharedAlbumAddition\x18\x15 \x01(\x0b\x32\\.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatMessengerSharedAlbumAdditionH\x00\x12\x94\x01\n&xmatMessengerSharedAlbumContentRemoval\x18\x16 \x01(\x0b\x32\x62.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatMessengerSharedAlbumContentRemovalH\x00\x12\x88\x01\n xmatMessengerSharedAlbumDeletion\x18\x17 \x01(\x0b\x32\\.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatMessengerSharedAlbumDeletionH\x00\x12\x84\x01\n\x1exmatMessengerSharedAlbumRename\x18\x18 \x01(\x0b\x32Z.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatMessengerSharedAlbumRenameH\x00\x12x\n\x18xmatMessengerSharedAlbum\x18\x19 \x01(\x0b\x32T.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatMessengerSharedAlbumH\x00\x12\x64\n\x0exmatThemeColor\x18\x1a \x01(\x0b\x32J.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatThemeColorH\x00\x12\x64\n\x0exmatThreadIcon\x18\x1b \x01(\x0b\x32J.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatThreadIconH\x00\x12l\n\x12xmatThreadNickname\x18\x1c \x01(\x0b\x32N.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatThreadNicknameH\x00\x12v\n\x17xmatThreadQuickReaction\x18\x1d \x01(\x0b\x32S.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatThreadQuickReactionH\x00\x12l\n\x12xmatUpdatePayments\x18\x1e \x01(\x0b\x32N.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatUpdatePaymentsH\x00\x12h\n\x10xmatPinMessageV2\x18\x1f \x01(\x0b\x32L.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatPinMessageV2H\x00\x12l\n\x12xmatUnpinMessageV2\x18  \x01(\x0b\x32N.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatUnpinMessageV2H\x00\x1a\xbc\x01\n\x13LimitSharingChanged\x12p\n\x0bsharingType\x18\x01 \x01(\x0e\x32[.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.LimitSharingChanged.SharingType\"3\n\x0bSharingType\x12\t\n\x05UNSET\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x0b\n\x07\x45NABLED\x10\x02\x1a\xa8\x01\n\x11GroupImageChanged\x12\x64\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32T.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupImageChanged.Action\"-\n\x06\x41\x63tion\x12\t\n\x05UNSET\x10\x00\x12\x0b\n\x07\x43HANGED\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x1a\xa0\x01\n\rMessagePinned\x12`\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32P.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.MessagePinned.Action\"-\n\x06\x41\x63tion\x12\t\n\x05UNSET\x10\x00\x12\n\n\x06PINNED\x10\x01\x12\x0c\n\x08UNPINNED\x10\x02\x1a\xc2\x01\n\x1dGroupMembershipAddModeChanged\x12l\n\x04mode\x18\x01 \x01(\x0e\x32^.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode\"3\n\x04Mode\x12\t\n\x05UNSET\x10\x00\x12\x0f\n\x0b\x41LL_MEMBERS\x10\x01\x12\x0f\n\x0b\x41\x44MINS_ONLY\x10\x02\x1a\xbc\x01\n\x11GroupAdminChanged\x12\x14\n\x0ctargetUserID\x18\x01 \x03(\t\x12\x64\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32T.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupAdminChanged.Action\"+\n\x06\x41\x63tion\x12\t\n\x05UNSET\x10\x00\x12\t\n\x05\x41\x44\x44\x45\x44\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x1a\xc8\x01\n\x17GroupParticipantChanged\x12\x14\n\x0ctargetUserID\x18\x01 \x03(\t\x12j\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32Z.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupParticipantChanged.Action\"+\n\x06\x41\x63tion\x12\t\n\x05UNSET\x10\x00\x12\t\n\x05\x41\x44\x44\x45\x44\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x1a-\n\x12XmatUnpinMessageV2\x12\x17\n\x0fpinnedMessageID\x18\x01 \x01(\t\x1a+\n\x10XmatPinMessageV2\x12\x17\n\x0fpinnedMessageID\x18\x01 \x01(\t\x1a\x80\x01\n\x12XmatUpdatePayments\x12\x14\n\x0creceiverName\x18\x01 \x01(\t\x12\x12\n\nsenderName\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x02\x12\x15\n\rtransactionID\x18\x04 \x01(\x03\x12\x19\n\x11transactionStatus\x18\x05 \x01(\x05\x1ah\n\x17XmatThreadQuickReaction\x12 \n\x18threadQuickReactionEmoji\x18\x01 \x01(\t\x12+\n#threadQuickReactionInstructionKeyID\x18\x02 \x01(\t\x1a=\n\x12XmatThreadNickname\x12\x15\n\rparticipantID\x18\x01 \x01(\x03\x12\x10\n\x08nickname\x18\x02 \x01(\t\x1a$\n\x0eXmatThreadIcon\x12\x12\n\nthreadIcon\x18\x01 \x01(\t\x1a\xc1\x01\n\x0eXmatThemeColor\x12\x0f\n\x07themeID\x18\x01 \x01(\t\x12\x12\n\nthemeColor\x18\x02 \x01(\t\x12\x10\n\x08gradient\x18\x03 \x03(\t\x12\x16\n\x0eshouldShowIcon\x18\x04 \x01(\x08\x12\x11\n\tthemeType\x18\x05 \x01(\x05\x12\x1a\n\x12\x61\x63\x63\x65ssibilityLabel\x18\x06 \x01(\t\x12\x1d\n\x15themeNameWithSubtitle\x18\x07 \x01(\t\x12\x12\n\nthemeEmoji\x18\x08 \x01(\t\x1a\x30\n\x18XmatMessengerSharedAlbum\x12\x14\n\x0cxmaDataclass\x18\x01 \x01(\t\x1a\x65\n\x1eXmatMessengerSharedAlbumRename\x12\x15\n\rsharedAlbumID\x18\x01 \x01(\x03\x12\x15\n\roldAlbumTitle\x18\x02 \x01(\t\x12\x15\n\rnewAlbumTitle\x18\x03 \x01(\t\x1aM\n XmatMessengerSharedAlbumDeletion\x12\x15\n\rsharedAlbumID\x18\x01 \x01(\x03\x12\x12\n\nalbumTitle\x18\x02 \x01(\t\x1a\xb7\x02\n&XmatMessengerSharedAlbumContentRemoval\x12\x15\n\rsharedAlbumID\x18\x01 \x01(\x03\x12\x91\x01\n\x11removedContentMap\x18\x02 \x03(\x0b\x32v.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.XmatMessengerSharedAlbumContentRemoval.RemovedContentTuple\x12\x1b\n\x13removedContentCount\x18\x03 \x01(\x03\x12\x12\n\nalbumTitle\x18\x04 \x01(\t\x1a\x31\n\x13RemovedContentTuple\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x80\x01\n XmatMessengerSharedAlbumAddition\x12\x15\n\rsharedAlbumID\x18\x01 \x01(\x03\x12\x12\n\nalbumTitle\x18\x02 \x01(\t\x12\x18\n\x10numOfAttachments\x18\x03 \x01(\x03\x12\x17\n\x0fisAlbumCreation\x18\x04 \x01(\x08\x1a\x46\n\x1aXmatMessengerQRCodeScanned\x12\x14\n\x0creceiverName\x18\x01 \x01(\t\x12\x12\n\nsenderName\x18\x02 \x01(\t\x1a[\n\x19XmatMessagingLimitSharing\x12\x12\n\nsenderName\x18\x01 \x01(\t\x12\x10\n\x08senderID\x18\x02 \x01(\t\x12\x18\n\x10limitSharingType\x18\x03 \x01(\t\x1a\x9a\x01\n\x0eXmatMagicWords\x12\x19\n\x11newMagicWordCount\x18\x01 \x01(\x03\x12\x1d\n\x15removedMagicWordCount\x18\x02 \x01(\x03\x12\x11\n\tmagicWord\x18\x03 \x01(\t\x12\x13\n\x0b\x65mojiEffect\x18\x04 \x01(\t\x12\x13\n\x0bisAllEdited\x18\x05 \x01(\x08\x12\x11\n\tthemeName\x18\x06 \x01(\t\x1a\xba\x03\n\x0bXmatLinkCTA\x12\x1e\n\x16linkCtaXmatPrimaryText\x18\x01 \x01(\t\x12\x1a\n\x12linkCtaXmatCtaText\x18\x02 \x01(\t\x12\x19\n\x11linkCtaXmatCtaURL\x18\x03 \x01(\t\x12\x1c\n\x14linkCtaXmatCtaIosURL\x18\x04 \x01(\t\x12\x12\n\nandroidUri\x18\x05 \x01(\t\x12\x10\n\x08\x61syncURL\x18\x06 \x01(\t\x12\x15\n\rwwwIsAsyncURL\x18\x07 \x01(\x08\x12\x14\n\x0cmsiteEnabled\x18\x08 \x01(\x08\x12\x19\n\x11hideUriInFallback\x18\t \x01(\x08\x12\x1e\n\x16showConfirmationDialog\x18\n \x01(\x08\x12\x14\n\x0cgraphPayload\x18\x0b \x01(\t\x12\x16\n\x0eidentifierName\x18\x0c \x01(\t\x12\x10\n\x08threadID\x18\r \x01(\t\x12\x19\n\x11hideCtaInFallback\x18\x0e \x01(\x08\x12$\n\x1c\x63txAdConversationStarterInfo\x18\x0f \x01(\t\x12\x0e\n\x06\x66\x62mUri\x18\x10 \x01(\t\x12\x17\n\x0finitiatorUserID\x18\x11 \x01(\t\x1ax\n+XmatInstantGameEncryptedDynamicCustomUpdate\x12\x12\n\nsenderName\x18\x01 \x01(\t\x12#\n\x1bmuteManagementAdminTextType\x18\x02 \x01(\t\x12\x10\n\x08gameName\x18\x03 \x01(\t\x1aT\n#XmatFriendRequestConfirmedEncrypted\x12\x15\n\rotherUserName\x18\x01 \x01(\t\x12\x16\n\x0eisTurnOnCohort\x18\x02 \x01(\t\x1a\xbe\x01\n\x17XmatDisappearingSetting\x12\x1f\n\x17\x64isappearingSettingTime\x18\x01 \x01(\x03\x12\"\n\x1aoldDisappearingSettingTime\x18\x02 \x01(\x03\x12$\n\x1c\x64isappearingSettingActorFbid\x18\x03 \x01(\x03\x12\x1b\n\x13newEphemeralityType\x18\x04 \x01(\x03\x12\x1b\n\x13oldEphemeralityType\x18\x05 \x01(\x03\x1aw\n\x1a\x44isappearingSettingChanged\x12*\n\"disappearingSettingDurationSeconds\x18\x01 \x01(\x05\x12-\n%oldDisappearingSettingDurationSeconds\x18\x02 \x01(\x05\x1a!\n\x0bIconChanged\x12\x12\n\nthreadIcon\x18\x01 \x01(\t\x1a\xad\x01\n\x07LinkCta\x12l\n\x0eukOsaAdminText\x18\x01 \x01(\x0b\x32R.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.LinkCta.UkOsaAdminTextH\x00\x1a)\n\x0eUkOsaAdminText\x12\x17\n\x0finitiatorUserID\x18\x02 \x01(\tB\t\n\x07\x63ontent\x1a)\n\x14QuickReactionChanged\x12\x11\n\temojiName\x18\x01 \x01(\t\x1a%\n\x10GroupNameChanged\x12\x11\n\tgroupName\x18\x01 \x01(\t\x1a\x39\n\x0fNicknameChanged\x12\x14\n\x0ctargetUserID\x18\x01 \x01(\t\x12\x10\n\x08nickname\x18\x02 \x01(\t\x1aL\n\x10\x43hatThemeChanged\x12\x11\n\tthemeName\x18\x01 \x01(\t\x12\x12\n\nthemeEmoji\x18\x02 \x01(\t\x12\x11\n\tthemeType\x18\x03 \x01(\x05\x42\t\n\x07\x63ontentB>Z<go.mau.fi/whatsmeow/proto/waArmadilloMiTransportAdminMessage')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waArmadilloMiTransportAdminMessage.WAArmadilloMiTransportAdminMessage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<go.mau.fi/whatsmeow/proto/waArmadilloMiTransportAdminMessage'
  _globals['_MITRANSPORTADMINMESSAGE']._serialized_start=116
  _globals['_MITRANSPORTADMINMESSAGE']._serialized_end=8031
  _globals['_MITRANSPORTADMINMESSAGE_LIMITSHARINGCHANGED']._serialized_start=3885
  _globals['_MITRANSPORTADMINMESSAGE_LIMITSHARINGCHANGED']._serialized_end=4073
  _globals['_MITRANSPORTADMINMESSAGE_LIMITSHARINGCHANGED_SHARINGTYPE']._serialized_start=4022
  _globals['_MITRANSPORTADMINMESSAGE_LIMITSHARINGCHANGED_SHARINGTYPE']._serialized_end=4073
  _globals['_MITRANSPORTADMINMESSAGE_GROUPIMAGECHANGED']._serialized_start=4076
  _globals['_MITRANSPORTADMINMESSAGE_GROUPIMAGECHANGED']._serialized_end=4244
  _globals['_MITRANSPORTADMINMESSAGE_GROUPIMAGECHANGED_ACTION']._serialized_start=4199
  _globals['_MITRANSPORTADMINMESSAGE_GROUPIMAGECHANGED_ACTION']._serialized_end=4244
  _globals['_MITRANSPORTADMINMESSAGE_MESSAGEPINNED']._serialized_start=4247
  _globals['_MITRANSPORTADMINMESSAGE_MESSAGEPINNED']._serialized_end=4407
  _globals['_MITRANSPORTADMINMESSAGE_MESSAGEPINNED_ACTION']._serialized_start=4362
  _globals['_MITRANSPORTADMINMESSAGE_MESSAGEPINNED_ACTION']._serialized_end=4407
  _globals['_MITRANSPORTADMINMESSAGE_GROUPMEMBERSHIPADDMODECHANGED']._serialized_start=4410
  _globals['_MITRANSPORTADMINMESSAGE_GROUPMEMBERSHIPADDMODECHANGED']._serialized_end=4604
  _globals['_MITRANSPORTADMINMESSAGE_GROUPMEMBERSHIPADDMODECHANGED_MODE']._serialized_start=4553
  _globals['_MITRANSPORTADMINMESSAGE_GROUPMEMBERSHIPADDMODECHANGED_MODE']._serialized_end=4604
  _globals['_MITRANSPORTADMINMESSAGE_GROUPADMINCHANGED']._serialized_start=4607
  _globals['_MITRANSPORTADMINMESSAGE_GROUPADMINCHANGED']._serialized_end=4795
  _globals['_MITRANSPORTADMINMESSAGE_GROUPADMINCHANGED_ACTION']._serialized_start=4752
  _globals['_MITRANSPORTADMINMESSAGE_GROUPADMINCHANGED_ACTION']._serialized_end=4795
  _globals['_MITRANSPORTADMINMESSAGE_GROUPPARTICIPANTCHANGED']._serialized_start=4798
  _globals['_MITRANSPORTADMINMESSAGE_GROUPPARTICIPANTCHANGED']._serialized_end=4998
  _globals['_MITRANSPORTADMINMESSAGE_GROUPPARTICIPANTCHANGED_ACTION']._serialized_start=4752
  _globals['_MITRANSPORTADMINMESSAGE_GROUPPARTICIPANTCHANGED_ACTION']._serialized_end=4795
  _globals['_MITRANSPORTADMINMESSAGE_XMATUNPINMESSAGEV2']._serialized_start=5000
  _globals['_MITRANSPORTADMINMESSAGE_XMATUNPINMESSAGEV2']._serialized_end=5045
  _globals['_MITRANSPORTADMINMESSAGE_XMATPINMESSAGEV2']._serialized_start=5047
  _globals['_MITRANSPORTADMINMESSAGE_XMATPINMESSAGEV2']._serialized_end=5090
  _globals['_MITRANSPORTADMINMESSAGE_XMATUPDATEPAYMENTS']._serialized_start=5093
  _globals['_MITRANSPORTADMINMESSAGE_XMATUPDATEPAYMENTS']._serialized_end=5221
  _globals['_MITRANSPORTADMINMESSAGE_XMATTHREADQUICKREACTION']._serialized_start=5223
  _globals['_MITRANSPORTADMINMESSAGE_XMATTHREADQUICKREACTION']._serialized_end=5327
  _globals['_MITRANSPORTADMINMESSAGE_XMATTHREADNICKNAME']._serialized_start=5329
  _globals['_MITRANSPORTADMINMESSAGE_XMATTHREADNICKNAME']._serialized_end=5390
  _globals['_MITRANSPORTADMINMESSAGE_XMATTHREADICON']._serialized_start=5392
  _globals['_MITRANSPORTADMINMESSAGE_XMATTHREADICON']._serialized_end=5428
  _globals['_MITRANSPORTADMINMESSAGE_XMATTHEMECOLOR']._serialized_start=5431
  _globals['_MITRANSPORTADMINMESSAGE_XMATTHEMECOLOR']._serialized_end=5624
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERSHAREDALBUM']._serialized_start=5626
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERSHAREDALBUM']._serialized_end=5674
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERSHAREDALBUMRENAME']._serialized_start=5676
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERSHAREDALBUMRENAME']._serialized_end=5777
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERSHAREDALBUMDELETION']._serialized_start=5779
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERSHAREDALBUMDELETION']._serialized_end=5856
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERSHAREDALBUMCONTENTREMOVAL']._serialized_start=5859
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERSHAREDALBUMCONTENTREMOVAL']._serialized_end=6170
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERSHAREDALBUMCONTENTREMOVAL_REMOVEDCONTENTTUPLE']._serialized_start=6121
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERSHAREDALBUMCONTENTREMOVAL_REMOVEDCONTENTTUPLE']._serialized_end=6170
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERSHAREDALBUMADDITION']._serialized_start=6173
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERSHAREDALBUMADDITION']._serialized_end=6301
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERQRCODESCANNED']._serialized_start=6303
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSENGERQRCODESCANNED']._serialized_end=6373
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSAGINGLIMITSHARING']._serialized_start=6375
  _globals['_MITRANSPORTADMINMESSAGE_XMATMESSAGINGLIMITSHARING']._serialized_end=6466
  _globals['_MITRANSPORTADMINMESSAGE_XMATMAGICWORDS']._serialized_start=6469
  _globals['_MITRANSPORTADMINMESSAGE_XMATMAGICWORDS']._serialized_end=6623
  _globals['_MITRANSPORTADMINMESSAGE_XMATLINKCTA']._serialized_start=6626
  _globals['_MITRANSPORTADMINMESSAGE_XMATLINKCTA']._serialized_end=7068
  _globals['_MITRANSPORTADMINMESSAGE_XMATINSTANTGAMEENCRYPTEDDYNAMICCUSTOMUPDATE']._serialized_start=7070
  _globals['_MITRANSPORTADMINMESSAGE_XMATINSTANTGAMEENCRYPTEDDYNAMICCUSTOMUPDATE']._serialized_end=7190
  _globals['_MITRANSPORTADMINMESSAGE_XMATFRIENDREQUESTCONFIRMEDENCRYPTED']._serialized_start=7192
  _globals['_MITRANSPORTADMINMESSAGE_XMATFRIENDREQUESTCONFIRMEDENCRYPTED']._serialized_end=7276
  _globals['_MITRANSPORTADMINMESSAGE_XMATDISAPPEARINGSETTING']._serialized_start=7279
  _globals['_MITRANSPORTADMINMESSAGE_XMATDISAPPEARINGSETTING']._serialized_end=7469
  _globals['_MITRANSPORTADMINMESSAGE_DISAPPEARINGSETTINGCHANGED']._serialized_start=7471
  _globals['_MITRANSPORTADMINMESSAGE_DISAPPEARINGSETTINGCHANGED']._serialized_end=7590
  _globals['_MITRANSPORTADMINMESSAGE_ICONCHANGED']._serialized_start=7592
  _globals['_MITRANSPORTADMINMESSAGE_ICONCHANGED']._serialized_end=7625
  _globals['_MITRANSPORTADMINMESSAGE_LINKCTA']._serialized_start=7628
  _globals['_MITRANSPORTADMINMESSAGE_LINKCTA']._serialized_end=7801
  _globals['_MITRANSPORTADMINMESSAGE_LINKCTA_UKOSAADMINTEXT']._serialized_start=7749
  _globals['_MITRANSPORTADMINMESSAGE_LINKCTA_UKOSAADMINTEXT']._serialized_end=7790
  _globals['_MITRANSPORTADMINMESSAGE_QUICKREACTIONCHANGED']._serialized_start=7803
  _globals['_MITRANSPORTADMINMESSAGE_QUICKREACTIONCHANGED']._serialized_end=7844
  _globals['_MITRANSPORTADMINMESSAGE_GROUPNAMECHANGED']._serialized_start=7846
  _globals['_MITRANSPORTADMINMESSAGE_GROUPNAMECHANGED']._serialized_end=7883
  _globals['_MITRANSPORTADMINMESSAGE_NICKNAMECHANGED']._serialized_start=7885
  _globals['_MITRANSPORTADMINMESSAGE_NICKNAMECHANGED']._serialized_end=7942
  _globals['_MITRANSPORTADMINMESSAGE_CHATTHEMECHANGED']._serialized_start=7944
  _globals['_MITRANSPORTADMINMESSAGE_CHATTHEMECHANGED']._serialized_end=8020
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import waSyncAction.WASyncAction_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SyncdSnapshotRecovery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    COLLECTIONNAME_FIELD_NUMBER: builtins.int
    MUTATIONRECORDS_FIELD_NUMBER: builtins.int
    COLLECTIONLTHASH_FIELD_NUMBER: builtins.int
    collectionName: builtins.str
    collectionLthash: builtins.bytes
    @property
    def version(self) -> global___SyncdVersion: ...
    @property
    def mutationRecords(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SyncdPlainTextRecord]: ...
    def __init__(
        self,
        *,
        version: global___SyncdVersion | None = ...,
        collectionName: builtins.str | None = ...,
        mutationRecords: collections.abc.Iterable[global___SyncdPlainTextRecord] | None = ...,
        collectionLthash: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["collectionLthash", b"collectionLthash", "collectionName", b"collectionName", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["collectionLthash", b"collectionLthash", "collectionName", b"collectionName", "mutationRecords", b"mutationRecords", "version", b"version"]) -> None: ...

global___SyncdSnapshotRecovery = SyncdSnapshotRecovery

@typing.final
class SyncdPlainTextRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    KEYID_FIELD_NUMBER: builtins.int
    MAC_FIELD_NUMBER: builtins.int
    keyID: builtins.bytes
    mac: builtins.bytes
    @property
    def value(self) -> waSyncAction.WASyncAction_pb2.SyncActionData: ...
    def __init__(
        self,
        *,
        value: waSyncAction.WASyncAction_pb2.SyncActionData | None = ...,
        keyID: builtins.bytes | None = ...,
        mac: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["keyID", b"keyID", "mac", b"mac", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["keyID", b"keyID", "mac", b"mac", "value", b"value"]) -> None: ...

global___SyncdPlainTextRecord = SyncdPlainTextRecord

@typing.final
class SyncdVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.int
    def __init__(
        self,
        *,
        version: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["version", b"version"]) -> None: ...

global___SyncdVersion = SyncdVersion



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waStatusAttributions/WAStatusAttributions.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'waStatusAttributions/WAStatusAttributions.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/waStatusAttributions/WAStatusAttributions.proto\x12\x14WAStatusAttributions\"\xdd\x0e\n\x11StatusAttribution\x12N\n\rstatusReshare\x18\x03 \x01(\x0b\x32\x35.WAStatusAttributions.StatusAttribution.StatusReshareH\x00\x12N\n\rexternalShare\x18\x04 \x01(\x0b\x32\x35.WAStatusAttributions.StatusAttribution.ExternalShareH\x00\x12>\n\x05music\x18\x05 \x01(\x0b\x32-.WAStatusAttributions.StatusAttribution.MusicH\x00\x12J\n\x0bgroupStatus\x18\x06 \x01(\x0b\x32\x33.WAStatusAttributions.StatusAttribution.GroupStatusH\x00\x12N\n\rrlAttribution\x18\x07 \x01(\x0b\x32\x35.WAStatusAttributions.StatusAttribution.RLAttributionH\x00\x12\\\n\x14\x61iCreatedAttribution\x18\x08 \x01(\x0b\x32<.WAStatusAttributions.StatusAttribution.AiCreatedAttributionH\x00\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.WAStatusAttributions.StatusAttribution.Type\x12\x11\n\tactionURL\x18\x02 \x01(\t\x1a\x96\x01\n\x14\x41iCreatedAttribution\x12S\n\x06source\x18\x01 \x01(\x0e\x32\x43.WAStatusAttributions.StatusAttribution.AiCreatedAttribution.Source\")\n\x06Source\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0eSTATUS_MIMICRY\x10\x01\x1a\xbe\x01\n\rRLAttribution\x12L\n\x06source\x18\x01 \x01(\x0e\x32<.WAStatusAttributions.StatusAttribution.RLAttribution.Source\"_\n\x06Source\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x18\n\x14RAY_BAN_META_GLASSES\x10\x01\x12\x17\n\x13OAKLEY_META_GLASSES\x10\x02\x12\x15\n\x11HYPERNOVA_GLASSES\x10\x03\x1a\x96\x02\n\rExternalShare\x12\x11\n\tactionURL\x18\x01 \x01(\t\x12L\n\x06source\x18\x02 \x01(\x0e\x32<.WAStatusAttributions.StatusAttribution.ExternalShare.Source\x12\x10\n\x08\x64uration\x18\x03 \x01(\x05\x12\x19\n\x11\x61\x63tionFallbackURL\x18\x04 \x01(\t\"w\n\x06Source\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tINSTAGRAM\x10\x01\x12\x0c\n\x08\x46\x41\x43\x45\x42OOK\x10\x02\x12\r\n\tMESSENGER\x10\x03\x12\x0b\n\x07SPOTIFY\x10\x04\x12\x0b\n\x07YOUTUBE\x10\x05\x12\r\n\tPINTEREST\x10\x06\x12\x0b\n\x07THREADS\x10\x07\x1a\xef\x02\n\rStatusReshare\x12L\n\x06source\x18\x01 \x01(\x0e\x32<.WAStatusAttributions.StatusAttribution.StatusReshare.Source\x12P\n\x08metadata\x18\x02 \x01(\x0b\x32>.WAStatusAttributions.StatusAttribution.StatusReshare.Metadata\x1ag\n\x08Metadata\x12\x10\n\x08\x64uration\x18\x01 \x01(\x05\x12\x12\n\nchannelJID\x18\x02 \x01(\t\x12\x18\n\x10\x63hannelMessageID\x18\x03 \x01(\x05\x12\x1b\n\x13hasMultipleReshares\x18\x04 \x01(\x08\"U\n\x06Source\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10INTERNAL_RESHARE\x10\x01\x12\x13\n\x0fMENTION_RESHARE\x10\x02\x12\x13\n\x0f\x43HANNEL_RESHARE\x10\x03\x1a \n\x0bGroupStatus\x12\x11\n\tauthorJID\x18\x01 \x01(\t\x1ay\n\x05Music\x12\x12\n\nauthorName\x18\x01 \x01(\t\x12\x0e\n\x06songID\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x19\n\x11\x61rtistAttribution\x18\x05 \x01(\t\x12\x12\n\nisExplicit\x18\x06 \x01(\x08\"\x89\x01\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07RESHARE\x10\x01\x12\x12\n\x0e\x45XTERNAL_SHARE\x10\x02\x12\t\n\x05MUSIC\x10\x03\x12\x12\n\x0eSTATUS_MENTION\x10\x04\x12\x10\n\x0cGROUP_STATUS\x10\x05\x12\x12\n\x0eRL_ATTRIBUTION\x10\x06\x12\x0e\n\nAI_CREATED\x10\x07\x42\x11\n\x0f\x61ttributionDataB0Z.go.mau.fi/whatsmeow/proto/waStatusAttributions')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waStatusAttributions.WAStatusAttributions_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.go.mau.fi/whatsmeow/proto/waStatusAttributions'
  _globals['_STATUSATTRIBUTION']._serialized_start=74
  _globals['_STATUSATTRIBUTION']._serialized_end=1959
  _globals['_STATUSATTRIBUTION_AICREATEDATTRIBUTION']._serialized_start=649
  _globals['_STATUSATTRIBUTION_AICREATEDATTRIBUTION']._serialized_end=799
  _globals['_STATUSATTRIBUTION_AICREATEDATTRIBUTION_SOURCE']._serialized_start=758
  _globals['_STATUSATTRIBUTION_AICREATEDATTRIBUTION_SOURCE']._serialized_end=799
  _globals['_STATUSATTRIBUTION_RLATTRIBUTION']._serialized_start=802
  _globals['_STATUSATTRIBUTION_RLATTRIBUTION']._serialized_end=992
  _globals['_STATUSATTRIBUTION_RLATTRIBUTION_SOURCE']._serialized_start=897
  _globals['_STATUSATTRIBUTION_RLATTRIBUTION_SOURCE']._serialized_end=992
  _globals['_STATUSATTRIBUTION_EXTERNALSHARE']._serialized_start=995
  _globals['_STATUSATTRIBUTION_EXTERNALSHARE']._serialized_end=1273
  _globals['_STATUSATTRIBUTION_EXTERNALSHARE_SOURCE']._serialized_start=1154
  _globals['_STATUSATTRIBUTION_EXTERNALSHARE_SOURCE']._serialized_end=1273
  _globals['_STATUSATTRIBUTION_STATUSRESHARE']._serialized_start=1276
  _globals['_STATUSATTRIBUTION_STATUSRESHARE']._serialized_end=1643
  _globals['_STATUSATTRIBUTION_STATUSRESHARE_METADATA']._serialized_start=1453
  _globals['_STATUSATTRIBUTION_STATUSRESHARE_METADATA']._serialized_end=1556
  _globals['_STATUSATTRIBUTION_STATUSRESHARE_SOURCE']._serialized_start=1558
  _globals['_STATUSATTRIBUTION_STATUSRESHARE_SOURCE']._serialized_end=1643
  _globals['_STATUSATTRIBUTION_GROUPSTATUS']._serialized_start=1645
  _globals['_STATUSATTRIBUTION_GROUPSTATUS']._serialized_end=1677
  _globals['_STATUSATTRIBUTION_MUSIC']._serialized_start=1679
  _globals['_STATUSATTRIBUTION_MUSIC']._serialized_end=1800
  _globals['_STATUSATTRIBUTION_TYPE']._serialized_start=1803
  _globals['_STATUSATTRIBUTION_TYPE']._serialized_end=1940
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waE2EGuest/WAWebProtobufsE2EGuest.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'waE2EGuest/WAWebProtobufsE2EGuest.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'waE2EGuest/WAWebProtobufsE2EGuest.proto\x12\x16WAWebProtobufsE2EGuest\"\x8e\x03\n\x07Message\x12\x14\n\x0c\x63onversation\x18\x01 \x01(\t\x12P\n\x13\x65xtendedTextMessage\x18\x06 \x01(\x0b\x32\x33.WAWebProtobufsE2EGuest.Message.ExtendedTextMessage\x12\x46\n\x12messageContextInfo\x18# \x01(\x0b\x32*.WAWebProtobufsE2EGuest.MessageContextInfo\x1a\x65\n\x13\x45xtendedTextMessage\x12\x0c\n\x04text\x18\x01 \x01(\t\x12@\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32+.WAWebProtobufsE2EGuest.Message.ContextInfo\x1al\n\x0b\x43ontextInfo\x12\x10\n\x08stanzaID\x18\x01 \x01(\t\x12\x13\n\x0bparticipant\x18\x02 \x01(\t\x12\x36\n\rquotedMessage\x18\x03 \x01(\x0b\x32\x1f.WAWebProtobufsE2EGuest.Message\"+\n\x12MessageContextInfo\x12\x15\n\rmessageSecret\x18\x03 \x01(\x0c\x42&Z$go.mau.fi/whatsmeow/proto/waE2EGuest')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waE2EGuest.WAWebProtobufsE2EGuest_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z$go.mau.fi/whatsmeow/proto/waE2EGuest'
  _globals['_MESSAGE']._serialized_start=68
  _globals['_MESSAGE']._serialized_end=466
  _globals['_MESSAGE_EXTENDEDTEXTMESSAGE']._serialized_start=255
  _globals['_MESSAGE_EXTENDEDTEXTMESSAGE']._serialized_end=356
  _globals['_MESSAGE_CONTEXTINFO']._serialized_start=358
  _globals['_MESSAGE_CONTEXTINFO']._serialized_end=466
  _globals['_MESSAGECONTEXTINFO']._serialized_start=468
  _globals['_MESSAGECONTEXTINFO']._serialized_end=511
# @@protoc_insertion_point(module_scope)
